# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Similarly, for package note feature
%undefine _package_note_file

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-Test-Signature
Version:	1.11
Release:	29.%{__distinit}%{__distvers}
Summary:	Automated SIGNATURE testing
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Signature
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Signature-%{version}.tar.gz
# Audrey Tang's public key (3C3501A0), from the Module::Signature 0.61 distribution
Source1:	AUDREY2006.pub
# Petr Pisar's public key (4B528393E6A3B0DFB2EF3A6412C9C5C767C6FAA2)
Source2:	ppisar2011.pub
Patch0:		Test-Signature-1.11-Fix-building-on-Perl-without-.-in-INC.patch
Patch1:		Test-Signature-1.11-Resign-patched-code.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
# Dependencies of bundled Module::Install
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(FindBin)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Module::Signature)
BuildRequires:	perl(Socket)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(File::Find::Rule)
BuildRequires:	perl(Test::Pod) >= 0.95
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# Package just skips (or, optionally, fails) testing if Module::Signature not installed
Requires:	perl(Module::Signature)
# Likewise, needs Socket to connect to keyserver
Requires:	perl(Socket)

%description
Module::Signature allows you to verify that a distribution has not been
tampered with. Test::Signature lets that be tested as part of the
distribution's test suite.

%prep
%setup -q -n Test-Signature-%{version}

# Fix building on Perl without "." in @INC (CPAN RT#121760)
%patch -P 0 -p1
# Required to pass tests after patching
%patch -P 1 -p1

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}
gpg2 --import %{SOURCE2}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
export GNUPGHOME=%{gnupghome}
make test

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Signature.3*

%changelog
* Fri May 26 2023 Paul Howarth <paul@city-fan.org> - 1.11-29
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Fri Mar 11 2022 Paul Howarth <paul@city-fan.org> - 1.11-26
- Work around FTBFS triggered by package note feature

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 1.11-16
- Perl 5.30 rebuild

* Thu Apr  5 2018 Paul Howarth <paul@city-fan.org> - 1.11-12
- Use mktemp to create GNUPGHOME, simplifying build process

* Thu May 18 2017 Paul Howarth <paul@city-fan.org> - 1.11-8
- Fix building on Perl without "." in @INC (CPAN RT#121760)

* Thu Apr  6 2017 Paul Howarth <paul@city-fan.org> - 1.11-7
- Use gnupg2 rather than gnupg (#1439206)
- Drop EL-5 support
  - Drop BuildRoot: and Group: tags
  - Drop buildroot cleaning in %%install
  - Drop explicit %%clean section

* Thu Oct  6 2016 Paul Howarth <paul@city-fan.org> - 1.11-5
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Jun 23 2015 Paul Howarth <paul@city-fan.org> - 1.11-3
- Perl 5.22 rebuild

* Wed Apr  8 2015 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
  - Compatibility with Module::Signature 0.75+
- Classify buildreqs by usage

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 1.10-18
- Drop %%defattr, redundant since rpm 4.4

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> - 1.10-12
- BR: perl(Cwd), perl(Exporter), perl(File::Path) and perl(File::Spec)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Importing keys with gnupg should always succeed

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 1.10-10
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 1.10-9
- Require Module::Signature
- Nobody else likes macros for commands

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.10-8
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 19 2010 Paul Howarth <paul@city-fan.org> - 1.10-7
- Fix build process to avoid the need to use ~/.gnupg
- Fix dist tag to work with RHEL6 Beta

* Thu Feb  4 2010 Paul Howarth <paul@city-fan.org> - 1.10-6
- Import from Fedora

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.10-5
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 07 2008 Iain Arnell <iarnell@gmail.com> - 1.10-2
- Remove explicit requires

* Fri Dec 05 2008 Iain Arnell - 1.10-1
- Specfile autogenerated by cpanspec 1.77
